pub enum Cmd {
Show 15 variants
CreateAlias(Box<Cmd>),
CurrentVersion(Box<Cmd>),
Deploy(Box<Cmd>),
DeployUnnamed(Box<Cmd>),
Download(Box<Cmd>),
FetchContractId(Box<Cmd>),
FetchHash(Box<Cmd>),
Publish(Box<Cmd>),
PublishHash(Box<Cmd>),
RegisterContract(Box<Cmd>),
RenameContract(Box<Cmd>),
UpdateContractAddress(Box<Cmd>),
UpdateContractOwner(Box<Cmd>),
Upgrade(Box<Cmd>),
Version(Cmd),
}Variants
CreateAlias(Box<Cmd>)
Create a local stellar contract alias from a named registry contract
CurrentVersion(Box<Cmd>)
Get the current (latest) version of a published Wasm
Deploy(Box<Cmd>)
Deploy a named contract from a published Wasm
DeployUnnamed(Box<Cmd>)
Deploy a contract from a published Wasm without registering a name
Download(Box<Cmd>)
Download a Wasm binary, optionally creating a local file
FetchContractId(Box<Cmd>)
Look up the contract ID of a deployed contract by name
FetchHash(Box<Cmd>)
Fetch the hash of a published Wasm binary
Publish(Box<Cmd>)
Publish Wasm to registry with package name and semantic version
PublishHash(Box<Cmd>)
Publish a Wasm hash (already uploaded) to registry
RegisterContract(Box<Cmd>)
Register an existing contract with a name in the registry
RenameContract(Box<Cmd>)
Rename a registered contract
UpdateContractAddress(Box<Cmd>)
Update the contract address of a registered contract
UpdateContractOwner(Box<Cmd>)
Update the owner of a registered contract
Upgrade(Box<Cmd>)
Upgrade a contract using a published Wasm
Version(Cmd)
Version of the scaffold-registry-cli